Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1268)

Unified Diff: chrome/browser/chromeos/arc/auth/arc_auth_info_fetcher.h

Issue 2655873002: Get enrollment token from DMServer when an Active Directory user uses ARC (Closed)
Patch Set: Remove unnecessary includes Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/arc/auth/arc_auth_info_fetcher.h
diff --git a/chrome/browser/chromeos/arc/auth/arc_auth_code_fetcher.h b/chrome/browser/chromeos/arc/auth/arc_auth_info_fetcher.h
similarity index 52%
rename from chrome/browser/chromeos/arc/auth/arc_auth_code_fetcher.h
rename to chrome/browser/chromeos/arc/auth/arc_auth_info_fetcher.h
index 7f9770e7e1cc2e884c3040d82a3ff1773d8b60a5..97413f09f97ce82f5b0485d7930ea28b3e969023 100644
--- a/chrome/browser/chromeos/arc/auth/arc_auth_code_fetcher.h
+++ b/chrome/browser/chromeos/arc/auth/arc_auth_info_fetcher.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_CHROMEOS_ARC_AUTH_ARC_AUTH_CODE_FETCHER_H_
-#define CHROME_BROWSER_CHROMEOS_ARC_AUTH_ARC_AUTH_CODE_FETCHER_H_
+#ifndef CHROME_BROWSER_CHROMEOS_ARC_AUTH_ARC_AUTH_INFO_FETCHER_H_
+#define CHROME_BROWSER_CHROMEOS_ARC_AUTH_ARC_AUTH_INFO_FETCHER_H_
#include <string>
@@ -11,20 +11,21 @@
namespace arc {
-// Interface to implement auth_code fetching.
-class ArcAuthCodeFetcher {
+// Interface to implement auth_code or enrollment token fetching.
+class ArcAuthInfoFetcher {
public:
- virtual ~ArcAuthCodeFetcher() = default;
+ virtual ~ArcAuthInfoFetcher() = default;
- // Fetches the |auth_code|. On success, |callback| is called with the
- // fetched |auth_code|. Otherwise, |callback| is called with empty string.
+ // Fetches the auth code or the enrollment token. On success, |callback| is
+ // called with the fetched |auth_info|. Otherwise, |callback| is called with
+ // empty string.
// Fetch() should be called once par instance, and it is expected that
Luis Héctor Chávez 2017/01/31 18:01:09 nit: not your fault, but please s/par/per/
Marton Hunyady 2017/02/01 12:21:51 Done.
// the inflight operation is cancelled without calling the |callback|
// when the instance is deleted.
- using FetchCallback = base::Callback<void(const std::string& auth_code)>;
+ using FetchCallback = base::Callback<void(const std::string& auth_info)>;
virtual void Fetch(const FetchCallback& callback) = 0;
};
} // namespace arc
-#endif // CHROME_BROWSER_CHROMEOS_ARC_AUTH_ARC_AUTH_CODE_FETCHER_H_
+#endif // CHROME_BROWSER_CHROMEOS_ARC_AUTH_ARC_AUTH_INFO_FETCHER_H_

Powered by Google App Engine
This is Rietveld 408576698